var moment = require('moment');

var mongodb = require("mongodb");

const config = require("../config/config");

const chalk = require("chalk");

class Database {
  constructor() {
    this.db = null;
  }

  async getDatabase(showOutputMessages) {
    if (showOutputMessages !== true) {
      showOutputMessages = false;
    }

    if (!this.db) {
      //console.log("Connecting to MongoDB");
      let self = this; //this.db = await mongodb.MongoClient.connect(uri);

      await mongodb.MongoClient.connect(config.database.uri(), {
        useNewUrlParser: true,
        useUnifiedTopology: true
      }, async function (err, client) {
        if (err) throw err;

        if (showOutputMessages) {
          console.log("Connected successfully to database");
        }

        self.db = await client.db(config.database.name);
      });
      await new Promise(resolve => setTimeout(resolve, 500));
    }

    return this.db;
  }

  async getState(strategyName, fingerprint) {
    // Get the database
    const db = await this.getDatabase();
    let result = await db.collection(`${strategyName}_states`).findOne({
      "fingerprint": fingerprint
    }, {
      _id: 1,
      stateName: 1,
      updatedAt: 1,
      data: 1
    }).then(data => {
      return data;
    });
    return result;
  }
  /* async getCacheTickers(provider, source, symbol, interval) {
       let query = {
          provider: provider,
          source: source,
          symbol: symbol,
          interval: interval,
      };
       if(!provider) { delete query.provider; }
      if(!source) { delete query.source; }
      if(!symbol) { delete query.symbol; }
      if(!interval) { delete query.interval; }
      
      let db = await this.getDatabase();
       let cacheTickers = await db
          .collection("CacheTickers")
          .find(query)
          .project({
              _id: 1,
              provider: 1,
              source: 1,
              symbol: 1,
              interval: 1,
              reset: 1,
          })
          .toArray();
       return cacheTickers;
  } */

  /* async getCachedCandles(provider, source, symbol, interval, limit) {
       limit = limit || 300;
      
      let db = await this.getDatabase();
       let candles = await db
          .collection(this.getCandleCacheCollectionName(provider, source))
          .find({
              symbol: symbol,
              interval: interval,
          })
          .project({
              timestamp: 1,
              open: 1,
              high: 1,
              low: 1,
              close: 1,
              volume: 1,
          })
          .sort({timestamp: -1})
          .limit(limit)
          .toArray();
       return candles.reverse();
  } */


  async updateState(strategyName, stateName, fingerprint, timestamp, data) {
    console.log(`Updating state: ${stateName} - ${new Date(timestamp * 1000)}`);
    let self = this;
    let state = null;
    await this.getDatabase().then(async db => {
      //const key = `${provider}_${source}_${symbol}_${interval}`;
      const doc = {
        stateName: stateName,
        updatedAt: moment().unix(),
        data: data
      };
      await db.collection(`${strategyName}_states`).updateOne({
        fingerprint: fingerprint
      }, {
        $set: doc
      }, {
        upsert: true // Note the upsert here

      }).then(async result => {
        state = await self.getState(strategyName, fingerprint);
        self.appendStateChange(strategyName, stateName, fingerprint, timestamp, data);

        if (result.result && result.result.upserted) {// Do nothing
        }
      });
    });
    return state;
  }

  async deleteState(strategyName, fingerprint) {
    const db = await this.getDatabase();
    await db.collection(`${strategyName}_states`).deleteOne({
      fingerprint: fingerprint
    }).then(result => {//result = insertResult.ops[0];
    });
  }

  async deleteStateChanges(strategyName, fingerprint) {
    const db = await this.getDatabase();
    await db.collection(`${strategyName}_state_changes`).deleteMany({
      fingerprint: fingerprint
    }).then(result => {//result = insertResult.ops[0];
    });
  }

  async appendStateChange(strategyName, stateName, fingerprint, timestamp, data) {
    let entry = {
      stateName: stateName,
      fingerprint: fingerprint,
      data: data,
      createdAt: timestamp,
      createdAtHuman: `${new Date(timestamp * 1000)}`
    };
    const db = await this.getDatabase();
    await db.collection(`${strategyName}_state_changes`).insertOne(entry).then(insertResult => {//result = insertResult.ops[0];
    });
  }

  async updateStrategy(name, property) {
    await this.getDatabase().then(db => {
      //const key = `${provider}_${source}_${symbol}_${interval}`;
      const doc = {
        property: property
      };
      db.collection("Strategies").updateOne({
        name: name
      }, {
        $set: doc
      }, {
        upsert: true // Note the upsert here

      }).then(async result => {
        if (result.result && result.result.upserted) {// Do nothing
        }
      });
    });
  }
  /* async deleteStrategy(id) {
       let query = { };
       if(id) { query._id = new mongodb.ObjectID(`${id}`); }
      if(provider) { query.provider = provider; }
      if(source) { query.source = source; }
      if(symbol) { query.symbol = symbol; }
      if(interval) { query.interval = interval; }
      
      let db = await this.getDatabase();
       let deletedCount = 0;
       await db
          .collection("Strategies")
          .deleteMany(query)
          .then(result => {
              deletedCount = result.deletedCount;
          });
       return deletedCount;
  } */

  /* async deleteCandles(provider, source, symbol, interval) {
       const self = this;
       await this.getDatabase().then( db => {
           db.collection(self.getCandleCacheCollectionName(provider, source))
              .deleteMany({
                  symbol: symbol,
                  interval: interval
              })
              .then(async result => {
              
              });
      });
   } */

  /* async addStateChange(strategyId, stateInfo) {
       const self = this;
      
      await this.getDatabase().then( db => {
           db.collection(self.getCandleCacheCollectionName(provider, source))
              .insertMany(candles)
              .then(result => {
                   //response = result;
               });
      });
   } */


}

module.exports = new Database();